@@ -20,17 +20,25 @@
 */
 
 #include <algorithm>
+#include <cstdlib>
+#include <cstring>
 #include <getopt.h>
 #include <iostream>
 #include <string>
 #include <vector>
 
 #include <osmium/io/any_input.hpp>
+#include <osmium/io/error.hpp>
+#include <osmium/io/file.hpp>
+#include <osmium/io/header.hpp>
 #include <osmium/io/input_iterator.hpp>
 #include <osmium/io/output_iterator.hpp>
 #include <osmium/io/pbf_output.hpp>
-#include <osmium/handler.hpp>
+#include <osmium/osm.hpp>
+#include <osmium/osm/box.hpp>
 #include <osmium/osm/entity_bits.hpp>
+#include <osmium/osm/node_ref.hpp>
+#include <osmium/osm/types.hpp>
 #include <osmium/util/memory.hpp>
 #include <osmium/util/verbose_output.hpp>
 
@@ -66,7 +74,7 @@ int main(int argc, char* argv[]) {
         switch (c) {
             case 'h':
                 print_help();
-                exit(return_code_ok);
+                std::exit(return_code_ok);
             case 'o':
                 output_filename = optarg;
                 break;
@@ -79,9 +87,9 @@ int main(int argc, char* argv[]) {
                           << "License: GNU GENERAL PUBLIC LICENSE Version 3 <http://gnu.org/licenses/gpl.html>.\n"
                           << "This is free software: you are free to change and redistribute it.\n"
                           << "There is NO WARRANTY, to the extent permitted by law.\n";
-                exit(return_code_ok);
+                std::exit(return_code_ok);
             default:
-                exit(return_code_fatal);
+                std::exit(return_code_fatal);
         }
     }
 
@@ -92,33 +100,32 @@ int main(int argc, char* argv[]) {
 
     if (output_filename.empty()) {
         std::cerr << "Missing -o/--output=OSMFILE option\n";
-        exit(return_code_cmdline);
+        std::exit(return_code_cmdline);
     }
 
     if (optind != argc - 1) {
         std::cerr << "Usage: osmcoastline_filter [OPTIONS] OSMFILE\n";
-        exit(return_code_cmdline);
+        std::exit(return_code_cmdline);
     }
 
     osmium::io::Header header;
     header.set("generator", "osmcoastline_filter");
-    header.add_box(osmium::Box(-180.0, -90.0, 180.0, 90.0));
+    header.add_box(osmium::Box{-180.0, -90.0, 180.0, 90.0});
 
-    osmium::io::File infile(argv[optind]);
+    osmium::io::File infile{argv[optind]};
 
     try {
-        osmium::io::Writer writer(output_filename, header);
+        osmium::io::Writer writer{output_filename, header};
         auto output_it = osmium::io::make_output_iterator(writer);
 
         std::vector<osmium::object_id_type> ids;
 
         vout << "Reading ways (1st pass through input file)...\n";
         {
-            osmium::io::Reader reader(infile, osmium::osm_entity_bits::way);
+            osmium::io::Reader reader{infile, osmium::osm_entity_bits::way};
             auto ways = osmium::io::make_input_iterator_range<const osmium::Way>(reader);
             for (const osmium::Way& way : ways) {
-                const char* natural = way.get_value_by_key("natural");
-                if (natural && !strcmp(natural, "coastline")) {
+                if (way.tags().has_tag("natural", "coastline")) {
                     *output_it++ = way;
                     for (const auto& nr : way.nodes()) {
                         ids.push_back(nr.ref());
@@ -134,7 +141,7 @@ int main(int argc, char* argv[]) {
 
         vout << "Reading nodes (2nd pass through input file)...\n";
         {
-            osmium::io::Reader reader(infile, osmium::osm_entity_bits::node);
+            osmium::io::Reader reader{infile, osmium::osm_entity_bits::node};
             auto nodes = osmium::io::make_input_iterator_range<const osmium::Node>(reader);
 
             auto first = ids.begin();
@@ -150,17 +157,16 @@ int main(int argc, char* argv[]) {
                     return true;
                 }
 
-                const char* natural = node.get_value_by_key("natural");
-                return natural && !strcmp(natural, "coastline");
+                return node.tags().has_tag("natural", "coastline");
             });
 
             reader.close();
         }
 
         writer.close();
-    } catch (osmium::io_error& e) {
+    } catch (const osmium::io_error& e) {
         std::cerr << "io error: " << e.what() << "'\n";
-        exit(return_code_fatal);
+        std::exit(return_code_fatal);
     }
 
     vout << "All done.\n";
