@@ -20,17 +20,25 @@
 */
 
 #include <algorithm>
-#include <cassert>
+#include <cerrno>
+#include <cstdlib>
 #include <fcntl.h>
 #include <getopt.h>
 #include <iostream>
+#include <iterator>
 #include <memory>
+#include <stdexcept>
 #include <string>
 #include <system_error>
-#include <sys/mman.h>
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <unistd.h>
+#include <vector>
+
+#ifndef _MSC_VER
+# include <unistd.h>
+#else
+# include <io.h>
+#endif
 
 #include <osmium/osm/undirected_segment.hpp>
 #include <osmium/util/memory_mapping.hpp>
@@ -39,7 +47,7 @@
 
 #include "return_codes.hpp"
 
-typedef std::vector<osmium::UndirectedSegment> segvec;
+using segvec = std::vector<osmium::UndirectedSegment>;
 
 class InputFile {
 
@@ -48,11 +56,11 @@ class InputFile {
 
 public:
 
-    InputFile(const std::string& filename) :
+    explicit InputFile(const std::string& filename) :
         m_filename(filename),
         m_fd(::open(filename.c_str(), O_RDONLY)) {
         if (m_fd == -1) {
-            throw std::system_error(errno, std::system_category(), std::string("Opening '") + filename + "' failed");
+            throw std::system_error{errno, std::system_category(), std::string{"Opening '"} + filename + "' failed"};
         }
     }
 
@@ -60,12 +68,12 @@ public:
         return m_fd;
     }
 
-    size_t size() const {
+    std::size_t size() const {
         struct stat s;
         if (::fstat(m_fd, &s) != 0) {
-            throw std::system_error(errno, std::system_category(), std::string("Can't get file size for '") + m_filename + "'");
+            throw std::system_error{errno, std::system_category(), std::string{"Can't get file size for '"} + m_filename + "'"};
         }
-        return size_t(s.st_size);
+        return std::size_t(s.st_size);
     }
 
 }; // class InputFile
@@ -74,7 +82,7 @@ void print_help() {
 }
 
 void add_segment(gdalcpp::Layer& layer, int change, const osmium::UndirectedSegment& segment) {
-    auto linestring = std::unique_ptr<OGRLineString>(new OGRLineString());
+    auto linestring = std::unique_ptr<OGRLineString>{new OGRLineString()};
     linestring->addPoint(segment.first().lon(), segment.first().lat());
     linestring->addPoint(segment.second().lon(), segment.second().lat());
 
@@ -133,7 +141,7 @@ int main(int argc, char *argv[]) {
             case 'h': {
                 std::cout << "Usage: " << argv[0] << " [OPTIONS] SEGFILE1 SEGFILE2\n";
                 print_help();
-                exit(return_code_ok);
+                std::exit(return_code_ok);
             }
             case 'V':
                 std::cout << "osmcoastline_segments version " OSMCOASTLINE_VERSION "\n"
@@ -141,7 +149,7 @@ int main(int argc, char *argv[]) {
                           << "License: GNU GENERAL PUBLIC LICENSE Version 3 <http://gnu.org/licenses/gpl.html>.\n"
                           << "This is free software: you are free to change and redistribute it.\n"
                           << "There is NO WARRANTY, to the extent permitted by law.\n";
-                exit(return_code_ok);
+                std::exit(return_code_ok);
             default:
                 break;
         }
@@ -149,24 +157,24 @@ int main(int argc, char *argv[]) {
 
     if (optind != argc - 2) {
         std::cerr << "Usage: " << argv[0] << " [OPTIONS] SEGFILE1 SEGFILE2\n";
-        exit(return_code_cmdline);
+        std::exit(return_code_cmdline);
     }
 
     segvec removed_segments;
     segvec added_segments;
 
     try {
-        InputFile file1(argv[optind]);
-        InputFile file2(argv[optind+1]);
+        InputFile file1{argv[optind]};
+        InputFile file2{argv[optind+1]};
 
-        osmium::util::TypedMemoryMapping<osmium::UndirectedSegment> m1(file1.size() / sizeof(osmium::UndirectedSegment), osmium::util::MemoryMapping::mapping_mode::readonly, file1.fd());
-        osmium::util::TypedMemoryMapping<osmium::UndirectedSegment> m2(file2.size() / sizeof(osmium::UndirectedSegment), osmium::util::MemoryMapping::mapping_mode::readonly, file2.fd());
+        osmium::util::TypedMemoryMapping<osmium::UndirectedSegment> m1{file1.size() / sizeof(osmium::UndirectedSegment), osmium::util::MemoryMapping::mapping_mode::readonly, file1.fd()};
+        osmium::util::TypedMemoryMapping<osmium::UndirectedSegment> m2{file2.size() / sizeof(osmium::UndirectedSegment), osmium::util::MemoryMapping::mapping_mode::readonly, file2.fd()};
 
         std::set_difference(m1.cbegin(), m1.cend(), m2.cbegin(), m2.cend(), std::back_inserter(removed_segments));
         std::set_difference(m2.cbegin(), m2.cend(), m1.cbegin(), m1.cend(), std::back_inserter(added_segments));
-    } catch (std::runtime_error& e) {
+    } catch (const std::runtime_error& e) {
         std::cerr << e.what() << "\n";
-        exit(return_code_fatal);
+        std::exit(return_code_fatal);
     }
 
     if (dump) {
